@@ -1,6 +1,7 @@
 """GitHub adapter implementation using REST API v3 and GraphQL API v4."""
 
 import builtins
+import logging
 import re
 from datetime import datetime
 from pathlib import Path
@@ -13,6 +14,8 @@ from ..core.env_loader import load_adapter_config, validate_adapter_config
 from ..core.models import Comment, Epic, Priority, SearchQuery, Task, TicketState
 from ..core.registry import AdapterRegistry
 
+logger = logging.getLogger(__name__)
+
 
 class GitHubStateMapping:
     """GitHub issue states and label-based extended states."""
@@ -162,6 +165,7 @@ class GitHubAdapter(BaseAdapter[Task]):
         """Initialize GitHub adapter.
 
         Args:
+        ----
             config: Configuration with:
                 - token: GitHub PAT (or GITHUB_TOKEN env var)
                 - owner: Repository owner (or GITHUB_OWNER env var)
@@ -228,7 +232,8 @@ class GitHubAdapter(BaseAdapter[Task]):
     def validate_credentials(self) -> tuple[bool, str]:
         """Validate that required credentials are present.
 
-        Returns:
+        Returns
+        -------
             (is_valid, error_message) - Tuple of validation result and error message
 
         """
@@ -309,9 +314,11 @@ class GitHubAdapter(BaseAdapter[Task]):
         """Convert GitHub milestone to Epic model.
 
         Args:
+        ----
             milestone: GitHub milestone data
 
         Returns:
+        -------
             Epic instance
 
         """
@@ -568,30 +575,72 @@ class GitHubAdapter(BaseAdapter[Task]):
 
         return self._task_from_github_issue(created_issue)
 
-    async def read(self, ticket_id: str) -> Task | None:
-        """Read a GitHub issue by number."""
+    async def read(self, ticket_id: str) -> Task | Epic | None:
+        """Read a GitHub issue OR milestone by number with unified find.
+
+        Tries to find the entity in the following order:
+        1. Issue (most common case) - returns Task
+        2. Milestone (project/epic) - returns Epic
+
+        Args:
+        ----
+            ticket_id: GitHub issue number or milestone number (as string)
+
+        Returns:
+        -------
+            Task if issue found,
+            Epic if milestone found,
+            None if not found as either type
+
+        Examples:
+        --------
+            >>> # Read issue #123
+            >>> task = await adapter.read("123")
+            >>> isinstance(task, Task)  # True
+            >>>
+            >>> # Read milestone #5
+            >>> epic = await adapter.read("5")
+            >>> isinstance(epic, Epic)  # True (if 5 is milestone, not issue)
+
+        """
         # Validate credentials before attempting operation
         is_valid, error_message = self.validate_credentials()
         if not is_valid:
             raise ValueError(error_message)
 
         try:
-            issue_number = int(ticket_id)
+            entity_number = int(ticket_id)
         except ValueError:
             return None
 
+        # Try reading as Issue first (most common case)
         try:
             response = await self.client.get(
-                f"/repos/{self.owner}/{self.repo}/issues/{issue_number}"
+                f"/repos/{self.owner}/{self.repo}/issues/{entity_number}"
             )
-            if response.status_code == 404:
-                return None
-            response.raise_for_status()
+            if response.status_code == 200:
+                response.raise_for_status()
+                issue = response.json()
+                logger.debug(f"Found GitHub entity as Issue: {ticket_id}")
+                return self._task_from_github_issue(issue)
+            elif response.status_code == 404:
+                # Not found as issue, will try milestone next
+                logger.debug(f"Not found as Issue ({ticket_id}), trying Milestone")
+        except httpx.HTTPError as e:
+            logger.debug(f"Error reading as Issue ({ticket_id}): {e}")
 
-            issue = response.json()
-            return self._task_from_github_issue(issue)
-        except httpx.HTTPError:
-            return None
+        # Try reading as Milestone (Epic)
+        try:
+            milestone = await self.get_milestone(entity_number)
+            if milestone:
+                logger.debug(f"Found GitHub entity as Milestone: {ticket_id}")
+                return milestone
+        except Exception as e:
+            logger.debug(f"Error reading as Milestone ({ticket_id}): {e}")
+
+        # Not found as either Issue or Milestone
+        logger.warning(f"GitHub entity not found: {ticket_id}")
+        return None
 
     async def update(self, ticket_id: str, updates: dict[str, Any]) -> Task | None:
         """Update a GitHub issue."""
@@ -1039,6 +1088,62 @@ class GitHubAdapter(BaseAdapter[Task]):
 
         return [self._milestone_to_epic(milestone) for milestone in response.json()]
 
+    async def delete_epic(self, epic_id: str) -> bool:
+        """Delete a GitHub milestone (Epic).
+
+        Args:
+        ----
+            epic_id: Milestone number (not ID) as a string
+
+        Returns:
+        -------
+            True if successfully deleted, False otherwise
+
+        Raises:
+        ------
+            ValueError: If credentials are invalid or epic_id is not a valid number
+
+        """
+        # Validate credentials
+        is_valid, error_message = self.validate_credentials()
+        if not is_valid:
+            raise ValueError(error_message)
+
+        try:
+            # Extract milestone number from epic_id
+            milestone_number = int(epic_id)
+        except ValueError as e:
+            raise ValueError(
+                f"Invalid milestone number '{epic_id}'. GitHub milestones use numeric IDs."
+            ) from e
+
+        try:
+            # Delete milestone using REST API
+            response = await self.client.delete(
+                f"/repos/{self.owner}/{self.repo}/milestones/{milestone_number}"
+            )
+
+            # GitHub returns 204 No Content on successful deletion
+            if response.status_code == 204:
+                return True
+
+            # Handle 404 errors gracefully
+            if response.status_code == 404:
+                return False
+
+            # Other errors - raise for visibility
+            response.raise_for_status()
+            return True
+
+        except httpx.HTTPStatusError as e:
+            if e.response.status_code == 404:
+                # Milestone not found
+                return False
+            # Re-raise other HTTP errors
+            raise ValueError(f"Failed to delete milestone: {e}") from e
+        except Exception as e:
+            raise ValueError(f"Failed to delete milestone: {e}") from e
+
     async def link_to_pull_request(self, issue_number: int, pr_number: int) -> bool:
         """Link an issue to a pull request using keywords."""
         # This is typically done through PR description keywords like "fixes #123"
@@ -1064,6 +1169,7 @@ class GitHubAdapter(BaseAdapter[Task]):
         """Create a pull request linked to an issue.
 
         Args:
+        ----
             ticket_id: Issue number to link the PR to
             base_branch: Target branch for the PR (default: main)
             head_branch: Source branch name (auto-generated if not provided)
@@ -1072,6 +1178,7 @@ class GitHubAdapter(BaseAdapter[Task]):
             draft: Create as draft PR
 
         Returns:
+        -------
             Dictionary with PR details including number, url, and branch
 
         """
@@ -1240,10 +1347,12 @@ Fixes #{issue_number}
         """Link an existing pull request to a ticket.
 
         Args:
+        ----
             ticket_id: Issue number to link the PR to
             pr_url: GitHub PR URL to link
 
         Returns:
+        -------
             Dictionary with link status and PR details
 
         """
@@ -1335,7 +1444,8 @@ Fixes #{issue_number}
     async def list_labels(self) -> builtins.list[dict[str, Any]]:
         """List all labels available in the repository.
 
-        Returns:
+        Returns
+        -------
             List of label dictionaries with 'id', 'name', and 'color' fields
 
         """
@@ -1361,6 +1471,7 @@ Fixes #{issue_number}
         """Update a GitHub milestone (Epic).
 
         Args:
+        ----
             milestone_number: Milestone number (not ID)
             updates: Dictionary with fields to update:
                 - title: Milestone title
@@ -1369,9 +1480,11 @@ Fixes #{issue_number}
                 - target_date: Due date in ISO format
 
         Returns:
+        -------
             Updated Epic object or None if not found
 
         Raises:
+        ------
             ValueError: If no fields to update
             httpx.HTTPError: If API request fails
 
@@ -1429,10 +1542,12 @@ Fixes #{issue_number}
         either a milestone number or the epic ID from the Epic object.
 
         Args:
+        ----
             epic_id: Epic ID (e.g., "milestone-5") or milestone number as string
             updates: Dictionary with fields to update
 
         Returns:
+        -------
             Updated Epic object or None if not found
 
         """
@@ -1458,18 +1573,22 @@ Fixes #{issue_number}
         that users can edit to add actual file attachments through the UI.
 
         Args:
+        ----
             issue_number: Issue number
             file_path: Path to file to attach
             comment: Optional comment text (defaults to "Attached: {filename}")
 
         Returns:
+        -------
             Dictionary with comment data and file info
 
         Raises:
+        ------
             FileNotFoundError: If file doesn't exist
             ValueError: If file too large (>25 MB)
 
         Note:
+        ----
             GitHub file size limit: 25 MB
             Supported: Images, videos, documents
 
@@ -1519,14 +1638,17 @@ Fixes #{issue_number}
         this method appends a markdown link to the milestone description.
 
         Args:
+        ----
             milestone_number: Milestone number
             file_url: URL to the file (external or GitHub-hosted)
             description: Description/title for the file
 
         Returns:
+        -------
             Updated Epic object
 
         Example:
+        -------
             await adapter.add_attachment_reference_to_milestone(
                 5,
                 "https://example.com/spec.pdf",
@@ -1562,14 +1684,17 @@ Fixes #{issue_number}
         - Milestones: Not supported, raises NotImplementedError with guidance
 
         Args:
+        ----
             ticket_id: Ticket identifier (issue number or milestone ID)
             file_path: Path to file to attach
             description: Optional description
 
         Returns:
+        -------
             Attachment metadata
 
         Raises:
+        ------
             NotImplementedError: For milestones (no native support)
             FileNotFoundError: If file doesn't exist
 
@@ -1595,12 +1720,14 @@ Fixes #{issue_number}
         Requires a project node ID (not numeric ID).
 
         Args:
+        ----
             project_id: GitHub Project V2 node ID (e.g., 'PVT_kwDOABcdefgh').
                        This is required for Projects V2. Can be found in the
                        project's GraphQL ID.
             limit: Maximum number of iterations to return (default: 50)
 
         Returns:
+        -------
             List of iteration dictionaries with fields:
                 - id: Iteration node ID
                 - title: Iteration title/name
@@ -1609,10 +1736,12 @@ Fixes #{issue_number}
                 - endDate: Calculated end date (startDate + duration)
 
         Raises:
+        ------
             ValueError: If project_id not provided or credentials invalid
             httpx.HTTPError: If GraphQL query fails
 
         Example:
+        -------
             >>> iterations = await adapter.list_cycles(
             ...     project_id="PVT_kwDOABCD1234",
             ...     limit=10
@@ -1621,6 +1750,7 @@ Fixes #{issue_number}
             ...     print(f"{iteration['title']}: {iteration['startDate']} ({iteration['duration']} days)")
 
         Note:
+        ----
             GitHub Projects V2 node IDs can be obtained via the GitHub GraphQL API.
             This is different from project numbers shown in the UI.
 
@@ -1696,9 +1826,11 @@ Fixes #{issue_number}
         tracking uses labels following the status:* convention (e.g., status:in_progress).
 
         Args:
+        ----
             issue_number: GitHub issue number
 
         Returns:
+        -------
             Dictionary with comprehensive status information:
                 - state: Native GitHub state ('open' or 'closed')
                 - status_label: Extended status from labels (in_progress, blocked, etc.)
@@ -1708,10 +1840,12 @@ Fixes #{issue_number}
                 - metadata: Additional issue metadata (assignees, milestone, etc.)
 
         Raises:
+        ------
             ValueError: If credentials invalid or issue not found
             httpx.HTTPError: If API request fails
 
         Example:
+        -------
             >>> status = await adapter.get_issue_status(123)
             >>> print(f"Issue #{status['number']}: {status['extended_state']}")
             >>> print(f"Native state: {status['state']}")
@@ -1719,6 +1853,7 @@ Fixes #{issue_number}
             ...     print(f"Label-based status: {status['status_label']}")
 
         Note:
+        ----
             GitHub's binary state model is extended via labels:
             - open + no label = OPEN
             - open + status:in-progress = IN_PROGRESS
@@ -1798,6 +1933,7 @@ Fixes #{issue_number}
         and extended label-based states.
 
         Returns:
+        -------
             List of status dictionaries with fields:
                 - name: Status name (e.g., 'open', 'in_progress', 'closed')
                 - type: Status type ('native' or 'extended')
@@ -1806,6 +1942,7 @@ Fixes #{issue_number}
                 - category: Status category (open, in_progress, done, etc.)
 
         Example:
+        -------
             >>> statuses = await adapter.list_issue_statuses()
             >>> for status in statuses:
             ...     print(f"{status['name']}: {status['description']}")
@@ -1813,6 +1950,7 @@ Fixes #{issue_number}
             ...         print(f"  Label: {status['label']}")
 
         Note:
+        ----
             GitHub natively supports only 'open' and 'closed' states.
             Extended statuses are implemented via labels following the
             status:* naming convention (e.g., status:in-progress).
@@ -1859,10 +1997,12 @@ Fixes #{issue_number}
         in that milestone. Otherwise, returns all repository labels.
 
         Args:
+        ----
             milestone_number: Optional milestone number to filter labels.
                             If None, returns all repository labels.
 
         Returns:
+        -------
             List of label dictionaries with fields:
                 - id: Label identifier (name)
                 - name: Label name
@@ -1871,6 +2011,7 @@ Fixes #{issue_number}
                 - usage_count: Number of issues using this label (if milestone filtered)
 
         Example:
+        -------
             >>> # Get all repository labels
             >>> all_labels = await adapter.list_project_labels()
             >>> print(f"Repository has {len(all_labels)} labels")
@@ -1881,6 +2022,7 @@ Fixes #{issue_number}
             ...     print(f"{label['name']}: used by {label['usage_count']} issues")
 
         Note:
+        ----
             Labels are repository-scoped in GitHub, not milestone-scoped.
             When filtering by milestone, this method queries issues in that
             milestone and extracts their unique labels.
