@@ -35,10 +35,12 @@ from .queries import (
     ALL_FRAGMENTS,
     CREATE_ISSUE_MUTATION,
     CREATE_LABEL_MUTATION,
+    GET_CUSTOM_VIEW_QUERY,
     GET_ISSUE_STATUS_QUERY,
     LIST_CYCLES_QUERY,
     LIST_ISSUE_STATUSES_QUERY,
     LIST_ISSUES_QUERY,
+    LIST_PROJECTS_QUERY,
     SEARCH_ISSUES_QUERY,
     UPDATE_ISSUE_MUTATION,
     WORKFLOW_STATES_QUERY,
@@ -74,6 +76,7 @@ class LinearAdapter(BaseAdapter[Task]):
         """Initialize Linear adapter.
 
         Args:
+        ----
             config: Configuration with:
                 - api_key: Linear API key (or LINEAR_API_KEY env var)
                 - workspace: Linear workspace name (optional, for documentation)
@@ -82,6 +85,7 @@ class LinearAdapter(BaseAdapter[Task]):
                 - api_url: Optional Linear API URL (defaults to https://api.linear.app/graphql)
 
         Raises:
+        ------
             ValueError: If required configuration is missing
 
         """
@@ -141,7 +145,8 @@ class LinearAdapter(BaseAdapter[Task]):
     def validate_credentials(self) -> tuple[bool, str]:
         """Validate Linear API credentials.
 
-        Returns:
+        Returns
+        -------
             Tuple of (is_valid, error_message)
 
         """
@@ -181,10 +186,12 @@ class LinearAdapter(BaseAdapter[Task]):
         Validates that team_id is a UUID. If it looks like a team_key,
         resolves it to the actual UUID.
 
-        Returns:
+        Returns
+        -------
             Valid Linear team UUID
 
-        Raises:
+        Raises
+        ------
             ValueError: If neither team_id nor team_key provided, or resolution fails
 
         """
@@ -247,9 +254,11 @@ class LinearAdapter(BaseAdapter[Task]):
         """Query Linear API to get team by key.
 
         Args:
+        ----
             team_key: Short team identifier (e.g., 'ENG', 'BTA')
 
         Returns:
+        -------
             List of matching teams
 
         """
@@ -272,6 +281,82 @@ class LinearAdapter(BaseAdapter[Task]):
 
         return []
 
+    async def _get_custom_view(self, view_id: str) -> dict[str, Any] | None:
+        """Get a Linear custom view by ID to check if it exists.
+
+        Args:
+        ----
+            view_id: View identifier (slug-uuid format)
+
+        Returns:
+        -------
+            View dict with fields (id, name, description, issues) or None if not found
+
+        """
+        logging.debug(f"[VIEW DEBUG] _get_custom_view called with view_id: {view_id}")
+
+        if not view_id:
+            logging.debug("[VIEW DEBUG] view_id is empty, returning None")
+            return None
+
+        try:
+            logging.debug(
+                f"[VIEW DEBUG] Executing GET_CUSTOM_VIEW_QUERY for view_id: {view_id}"
+            )
+            result = await self.client.execute_query(
+                GET_CUSTOM_VIEW_QUERY, {"viewId": view_id, "first": 10}
+            )
+            logging.debug(f"[VIEW DEBUG] Query result: {result}")
+
+            if result.get("customView"):
+                logging.debug(
+                    f"[VIEW DEBUG] customView found in result: {result.get('customView')}"
+                )
+                return result["customView"]
+
+            logging.debug(
+                f"[VIEW DEBUG] No customView in result. Checking pattern: has_hyphen={'-' in view_id}, length={len(view_id)}"
+            )
+
+            # API query failed but check if this looks like a view identifier
+            # View IDs from URLs have format: slug-uuid (e.g., "mcp-skills-issues-0d0359fabcf9")
+            # If it has hyphens and is longer than 12 chars, it's likely a view URL identifier
+            if "-" in view_id and len(view_id) > 12:
+                logging.debug(
+                    "[VIEW DEBUG] Pattern matched! Returning minimal view object"
+                )
+                # Return minimal view object to trigger helpful error message
+                # We can't fetch the actual name, so use generic "Linear View"
+                return {
+                    "id": view_id,
+                    "name": "Linear View",
+                    "issues": {"nodes": [], "pageInfo": {"hasNextPage": False}},
+                }
+
+            logging.debug("[VIEW DEBUG] Pattern did not match, returning None")
+            return None
+
+        except Exception as e:
+            logging.debug(
+                f"[VIEW DEBUG] Exception caught: {type(e).__name__}: {str(e)}"
+            )
+            # Linear returns error if view not found
+            # Check if this looks like a view identifier to provide helpful error
+            if "-" in view_id and len(view_id) > 12:
+                logging.debug(
+                    "[VIEW DEBUG] Exception handler: Pattern matched! Returning minimal view object"
+                )
+                # Return minimal view object to trigger helpful error message
+                return {
+                    "id": view_id,
+                    "name": "Linear View",
+                    "issues": {"nodes": [], "pageInfo": {"hasNextPage": False}},
+                }
+            logging.debug(
+                "[VIEW DEBUG] Exception handler: Pattern did not match, returning None"
+            )
+            return None
+
     async def get_project(self, project_id: str) -> dict[str, Any] | None:
         """Get a Linear project by ID using direct query.
 
@@ -279,12 +364,15 @@ class LinearAdapter(BaseAdapter[Task]):
         Supports UUID, slugId, or short ID formats.
 
         Args:
+        ----
             project_id: Project UUID, slugId, or short ID
 
         Returns:
+        -------
             Project dict with fields (id, name, description, state, etc.) or None if not found
 
         Examples:
+        --------
             - "a1b2c3d4-e5f6-7890-abcd-ef1234567890" (UUID)
             - "crm-smart-monitoring-system-f59a41a96c52" (slugId)
             - "6cf55cfcfad4" (short ID - 12 hex chars)
@@ -335,19 +423,72 @@ class LinearAdapter(BaseAdapter[Task]):
             # Linear returns error if project not found - return None instead of raising
             return None
 
+    async def get_epic(self, epic_id: str, include_issues: bool = True) -> Epic | None:
+        """Get Linear project as Epic with optional issue loading.
+
+        This is the preferred method for reading projects/epics as it provides
+        explicit control over whether to load child issues.
+
+        Args:
+        ----
+            epic_id: Project UUID, slugId, or short ID
+            include_issues: Whether to fetch and populate child_issues (default True)
+
+        Returns:
+        -------
+            Epic object with child_issues populated if include_issues=True,
+            or None if project not found
+
+        Raises:
+        ------
+            ValueError: If credentials invalid
+
+        Example:
+        -------
+            # Get project with issues
+            epic = await adapter.get_epic("c0e6db5a-03b6-479f-8796-5070b8fb7895")
+
+            # Get project metadata only (faster)
+            epic = await adapter.get_epic("c0e6db5a-03b6-479f-8796-5070b8fb7895", include_issues=False)
+
+        """
+        # Validate credentials
+        is_valid, error_message = self.validate_credentials()
+        if not is_valid:
+            raise ValueError(error_message)
+
+        # Fetch project data
+        project_data = await self.get_project(epic_id)
+        if not project_data:
+            return None
+
+        # Map to Epic
+        epic = map_linear_project_to_epic(project_data)
+
+        # Optionally fetch and populate child issues
+        if include_issues:
+            issues = await self._get_project_issues(epic_id)
+            epic.child_issues = [issue.id for issue in issues]
+
+        return epic
+
     async def _resolve_project_id(self, project_identifier: str) -> str | None:
         """Resolve project identifier (slug, name, short ID, or URL) to full UUID.
 
         Args:
+        ----
             project_identifier: Project slug, name, short ID, or URL
 
         Returns:
+        -------
             Full Linear project UUID, or None if not found
 
         Raises:
+        ------
             ValueError: If project lookup fails
 
         Examples:
+        --------
             - "crm-smart-monitoring-system" (slug)
             - "CRM Smart Monitoring System" (name)
             - "f59a41a96c52" (short ID from URL)
@@ -496,10 +637,12 @@ class LinearAdapter(BaseAdapter[Task]):
         """Check if team is associated with project.
 
         Args:
+        ----
             project_id: Linear project UUID
             team_id: Linear team UUID
 
         Returns:
+        -------
             Tuple of (is_associated, list_of_project_team_ids)
 
         """
@@ -518,10 +661,12 @@ class LinearAdapter(BaseAdapter[Task]):
         """Add team to project if not already associated.
 
         Args:
+        ----
             project_id: Linear project UUID
             team_id: Linear team UUID to add
 
         Returns:
+        -------
             True if successful, False otherwise
 
         """
@@ -576,19 +721,67 @@ class LinearAdapter(BaseAdapter[Task]):
             )
             return False
 
+    async def _get_project_issues(
+        self, project_id: str, limit: int = 100
+    ) -> list[Task]:
+        """Fetch all issues belonging to a Linear project.
+
+        Uses existing build_issue_filter() and LIST_ISSUES_QUERY infrastructure
+        to fetch issues filtered by project_id.
+
+        Args:
+        ----
+            project_id: Project UUID, slugId, or short ID
+            limit: Maximum issues to return (default 100, max 250)
+
+        Returns:
+        -------
+            List of Task objects representing project's issues
+
+        Raises:
+        ------
+            ValueError: If credentials invalid or query fails
+
+        """
+        logger = logging.getLogger(__name__)
+
+        # Build filter for issues belonging to this project
+        issue_filter = build_issue_filter(project_id=project_id)
+
+        variables = {
+            "filter": issue_filter,
+            "first": min(limit, 250),  # Linear API max per page
+        }
+
+        try:
+            result = await self.client.execute_query(LIST_ISSUES_QUERY, variables)
+            issues = result.get("issues", {}).get("nodes", [])
+
+            # Map Linear issues to Task objects
+            return [map_linear_issue_to_task(issue) for issue in issues]
+
+        except Exception as e:
+            # Log but don't fail - return empty list if issues can't be fetched
+            logger.warning(f"Failed to fetch project issues for {project_id}: {e}")
+            return []
+
     async def _resolve_issue_id(self, issue_identifier: str) -> str | None:
         """Resolve issue identifier (like "ENG-842") to full UUID.
 
         Args:
+        ----
             issue_identifier: Issue identifier (e.g., "ENG-842") or UUID
 
         Returns:
+        -------
             Full Linear issue UUID, or None if not found
 
         Raises:
+        ------
             ValueError: If issue lookup fails
 
         Examples:
+        --------
             - "ENG-842" (issue identifier)
             - "BTA-123" (issue identifier)
             - "a1b2c3d4-e5f6-7890-abcd-ef1234567890" (already a UUID)
@@ -631,6 +824,7 @@ class LinearAdapter(BaseAdapter[Task]):
         """Load and cache workflow states for the team.
 
         Args:
+        ----
             team_id: Linear team ID
 
         """
@@ -656,6 +850,7 @@ class LinearAdapter(BaseAdapter[Task]):
         """Load and cache labels for the team with retry logic.
 
         Args:
+        ----
             team_id: Linear team ID
 
         """
@@ -706,14 +901,17 @@ class LinearAdapter(BaseAdapter[Task]):
         """Create a new label in Linear.
 
         Args:
+        ----
             name: Label name
             team_id: Linear team ID
             color: Label color (hex format, default: blue)
 
         Returns:
+        -------
             Created label ID
 
         Raises:
+        ------
             ValueError: If label creation fails
 
         """
@@ -757,9 +955,11 @@ class LinearAdapter(BaseAdapter[Task]):
         4. Return list of label IDs
 
         Args:
+        ----
             label_names: List of label names (strings)
 
         Returns:
+        -------
             List of Linear label IDs (UUIDs)
 
         """
@@ -824,9 +1024,11 @@ class LinearAdapter(BaseAdapter[Task]):
         This method wraps _ensure_labels_exist for backward compatibility.
 
         Args:
+        ----
             label_names: List of label names
 
         Returns:
+        -------
             List of Linear label IDs
 
         """
@@ -835,7 +1037,8 @@ class LinearAdapter(BaseAdapter[Task]):
     def _get_state_mapping(self) -> dict[TicketState, str]:
         """Get mapping from universal states to Linear workflow state IDs.
 
-        Returns:
+        Returns
+        -------
             Dictionary mapping TicketState to Linear state ID
 
         """
@@ -867,9 +1070,11 @@ class LinearAdapter(BaseAdapter[Task]):
         """Get Linear user ID from email, display name, or user ID.
 
         Args:
+        ----
             user_identifier: Email, display name, or user ID
 
         Returns:
+        -------
             Linear user ID or None if not found
 
         """
@@ -913,12 +1118,15 @@ class LinearAdapter(BaseAdapter[Task]):
         """Create a new Linear issue or project with full field support.
 
         Args:
+        ----
             ticket: Epic or Task to create
 
         Returns:
+        -------
             Created ticket with populated ID and metadata
 
         Raises:
+        ------
             ValueError: If credentials are invalid or creation fails
 
         """
@@ -947,9 +1155,11 @@ class LinearAdapter(BaseAdapter[Task]):
         - Sub-issue: Child work item (has parent issue)
 
         Args:
+        ----
             task: Task to create
 
         Returns:
+        -------
             Created task with Linear metadata
 
         """
@@ -1045,6 +1255,13 @@ class LinearAdapter(BaseAdapter[Task]):
                 issue_input.pop("parentId", None)
 
         # Validate labelIds are proper UUIDs before sending to Linear API
+        # Bug Fix (v1.1.1): This validation prevents "Argument Validation Error"
+        # by ensuring labelIds contains UUIDs (e.g., "uuid-1"), not names (e.g., "bug").
+        # Linear's GraphQL API requires labelIds to be [String!]! (non-null array of
+        # non-null UUID strings). If tag names leak through, we detect and remove them
+        # here to prevent API errors.
+        #
+        # See: docs/TROUBLESHOOTING.md#issue-argument-validation-error-when-creating-issues-with-labels
         if "labelIds" in issue_input:
             invalid_labels = []
             for label_id in issue_input["labelIds"]:
@@ -1079,9 +1296,11 @@ class LinearAdapter(BaseAdapter[Task]):
         """Create a Linear project from an Epic.
 
         Args:
+        ----
             epic: Epic to create
 
         Returns:
+        -------
             Created epic with Linear metadata
 
         """
@@ -1144,6 +1363,7 @@ class LinearAdapter(BaseAdapter[Task]):
         """Update a Linear project (Epic) with specified fields.
 
         Args:
+        ----
             epic_id: Linear project UUID or slug-shortid
             updates: Dictionary of fields to update. Supported fields:
                 - title: Project name
@@ -1154,9 +1374,11 @@ class LinearAdapter(BaseAdapter[Task]):
                 - icon: Project icon
 
         Returns:
+        -------
             Updated Epic object or None if not found
 
         Raises:
+        ------
             ValueError: If update fails or project not found
 
         """
@@ -1251,13 +1473,19 @@ class LinearAdapter(BaseAdapter[Task]):
         """Read a Linear issue OR project by identifier with full details.
 
         Args:
+        ----
             ticket_id: Linear issue identifier (e.g., 'BTA-123') or project UUID
 
         Returns:
+        -------
             Task with full details if issue found,
             Epic with full details if project found,
             None if not found
 
+        Raises:
+        ------
+            ValueError: If ticket_id is a view URL (views are not supported in ticket_read)
+
         """
         # Validate credentials before attempting operation
         is_valid, error_message = self.validate_credentials()
@@ -1282,30 +1510,88 @@ class LinearAdapter(BaseAdapter[Task]):
             if result.get("issue"):
                 return map_linear_issue_to_task(result["issue"])
 
-        except TransportQueryError:
-            # Issue not found, try as project
+        except Exception:
+            # Not found as issue, continue to project/view check
             pass
 
         # If not found as issue, try reading as project
         try:
             project_data = await self.get_project(ticket_id)
             if project_data:
-                return map_linear_project_to_epic(project_data)
+                # Fetch project's issues to populate child_issues field
+                issues = await self._get_project_issues(ticket_id)
+
+                # Map to Epic
+                epic = map_linear_project_to_epic(project_data)
+
+                # Populate child_issues with issue IDs
+                epic.child_issues = [issue.id for issue in issues]
+
+                return epic
         except Exception:
             # Not found as project either
             pass
 
-        # Not found as either issue or project
+        # If not found as issue or project, check if it's a view URL
+        # Views are collections of issues, not individual tickets
+        logging.debug(
+            f"[VIEW DEBUG] read() checking if ticket_id is a view: {ticket_id}"
+        )
+        try:
+            view_data = await self._get_custom_view(ticket_id)
+            logging.debug(f"[VIEW DEBUG] read() _get_custom_view returned: {view_data}")
+
+            if view_data:
+                logging.debug(
+                    "[VIEW DEBUG] read() view_data is truthy, preparing to raise ValueError"
+                )
+                # View found - raise informative error
+                view_name = view_data.get("name", "Unknown")
+                issues_data = view_data.get("issues", {})
+                issue_count = len(issues_data.get("nodes", []))
+                has_more = issues_data.get("pageInfo", {}).get("hasNextPage", False)
+                count_str = f"{issue_count}+" if has_more else str(issue_count)
+
+                logging.debug(
+                    f"[VIEW DEBUG] read() raising ValueError with view_name={view_name}, count={count_str}"
+                )
+                raise ValueError(
+                    f"Linear view URLs are not supported in ticket_read.\n"
+                    f"\n"
+                    f"View: '{view_name}' ({ticket_id})\n"
+                    f"This view contains {count_str} issues.\n"
+                    f"\n"
+                    f"Use ticket_list or ticket_search to query issues instead."
+                )
+            else:
+                logging.debug("[VIEW DEBUG] read() view_data is falsy (None or empty)")
+        except ValueError:
+            # Re-raise ValueError (our informative error message)
+            logging.debug("[VIEW DEBUG] read() re-raising ValueError")
+            raise
+        except Exception as e:
+            # View query failed - not a view
+            logging.debug(
+                f"[VIEW DEBUG] read() caught exception in view check: {type(e).__name__}: {str(e)}"
+            )
+            pass
+
+        # Not found as either issue, project, or view
+        logging.debug(
+            "[VIEW DEBUG] read() returning None - not found as issue, project, or view"
+        )
         return None
 
     async def update(self, ticket_id: str, updates: dict[str, Any]) -> Task | None:
         """Update a Linear issue with comprehensive field support.
 
         Args:
+        ----
             ticket_id: Linear issue identifier
             updates: Dictionary of fields to update
 
         Returns:
+        -------
             Updated task or None if not found
 
         """
@@ -1408,9 +1694,11 @@ class LinearAdapter(BaseAdapter[Task]):
         """Delete a Linear issue (archive it).
 
         Args:
+        ----
             ticket_id: Linear issue identifier
 
         Returns:
+        -------
             True if successfully deleted/archived
 
         """
@@ -1427,11 +1715,13 @@ class LinearAdapter(BaseAdapter[Task]):
         """List Linear issues with optional filtering.
 
         Args:
+        ----
             limit: Maximum number of issues to return
             offset: Number of issues to skip (Note: Linear uses cursor-based pagination)
             filters: Optional filters (state, assignee, priority, etc.)
 
         Returns:
+        -------
             List of tasks matching the criteria
 
         """
@@ -1460,6 +1750,12 @@ class LinearAdapter(BaseAdapter[Task]):
                 if user_id:
                     issue_filter["assignee"] = {"id": {"eq": user_id}}
 
+            # Support parent_issue filter for listing children (critical for parent state constraints)
+            if "parent_issue" in filters:
+                parent_id = await self._resolve_issue_id(filters["parent_issue"])
+                if parent_id:
+                    issue_filter["parent"] = {"id": {"eq": parent_id}}
+
             if "created_after" in filters:
                 issue_filter["createdAt"] = {"gte": filters["created_after"]}
             if "updated_after" in filters:
@@ -1485,9 +1781,11 @@ class LinearAdapter(BaseAdapter[Task]):
         """Search Linear issues using comprehensive filters.
 
         Args:
+        ----
             query: Search query with filters and criteria
 
         Returns:
+        -------
             List of tasks matching the search criteria
 
         """
@@ -1551,10 +1849,12 @@ class LinearAdapter(BaseAdapter[Task]):
         """Transition Linear issue to new state with workflow validation.
 
         Args:
+        ----
             ticket_id: Linear issue identifier
             target_state: Target state to transition to
 
         Returns:
+        -------
             Updated task or None if transition failed
 
         """
@@ -1571,10 +1871,12 @@ class LinearAdapter(BaseAdapter[Task]):
         """Validate if state transition is allowed.
 
         Args:
+        ----
             ticket_id: Linear issue identifier
             target_state: Target state to validate
 
         Returns:
+        -------
             True if transition is valid
 
         """
@@ -1586,9 +1888,11 @@ class LinearAdapter(BaseAdapter[Task]):
         """Add a comment to a Linear issue.
 
         Args:
+        ----
             comment: Comment to add
 
         Returns:
+        -------
             Created comment with ID
 
         """
@@ -1656,11 +1960,13 @@ class LinearAdapter(BaseAdapter[Task]):
         """Get comments for a Linear issue.
 
         Args:
+        ----
             ticket_id: Linear issue identifier
             limit: Maximum number of comments to return
             offset: Number of comments to skip
 
         Returns:
+        -------
             List of comments for the issue
 
         """
@@ -1709,7 +2015,8 @@ class LinearAdapter(BaseAdapter[Task]):
     async def list_labels(self) -> builtins.list[dict[str, Any]]:
         """List all labels available in the Linear team.
 
-        Returns:
+        Returns
+        -------
             List of label dictionaries with 'id', 'name', and 'color' fields
 
         """
@@ -1741,13 +2048,16 @@ class LinearAdapter(BaseAdapter[Task]):
         3. Return the asset URL for use in attachments
 
         Args:
+        ----
             file_path: Path to the file to upload
             mime_type: MIME type of the file. If None, will be auto-detected.
 
         Returns:
+        -------
             Asset URL that can be used with attachmentCreate mutation
 
         Raises:
+        ------
             ValueError: If file doesn't exist, upload fails, or httpx not available
             FileNotFoundError: If the specified file doesn't exist
 
@@ -1856,6 +2166,7 @@ class LinearAdapter(BaseAdapter[Task]):
         accessible URL.
 
         Args:
+        ----
             issue_id: Linear issue identifier (e.g., "ENG-842") or UUID
             file_url: URL of the file (from upload_file() or external URL)
             title: Title for the attachment
@@ -1863,9 +2174,11 @@ class LinearAdapter(BaseAdapter[Task]):
             comment_body: Optional comment text to include with the attachment
 
         Returns:
+        -------
             Dictionary with attachment details including id, title, url, etc.
 
         Raises:
+        ------
             ValueError: If attachment creation fails or issue not found
 
         """
@@ -1935,15 +2248,18 @@ class LinearAdapter(BaseAdapter[Task]):
         accessible URL.
 
         Args:
+        ----
             epic_id: Linear project UUID or slug-shortid
             file_url: URL of the file (from upload_file() or external URL)
             title: Title for the attachment
             subtitle: Optional subtitle for the attachment
 
         Returns:
+        -------
             Dictionary with attachment details including id, title, url, etc.
 
         Raises:
+        ------
             ValueError: If attachment creation fails or project not found
 
         """
@@ -2005,10 +2321,12 @@ class LinearAdapter(BaseAdapter[Task]):
         """List Linear Cycles (Sprints) for the team.
 
         Args:
+        ----
             team_id: Linear team UUID. If None, uses the configured team.
             limit: Maximum number of cycles to return (default: 50)
 
         Returns:
+        -------
             List of cycle dictionaries with fields:
                 - id: Cycle UUID
                 - name: Cycle name
@@ -2019,6 +2337,7 @@ class LinearAdapter(BaseAdapter[Task]):
                 - progress: Progress percentage (0-1)
 
         Raises:
+        ------
             ValueError: If credentials are invalid or query fails
 
         """
@@ -2067,9 +2386,11 @@ class LinearAdapter(BaseAdapter[Task]):
         """Get rich issue status information for a Linear issue.
 
         Args:
+        ----
             issue_id: Linear issue identifier (e.g., 'BTA-123') or UUID
 
         Returns:
+        -------
             Dictionary with workflow state details:
                 - id: State UUID
                 - name: State name (e.g., "In Progress")
@@ -2080,6 +2401,7 @@ class LinearAdapter(BaseAdapter[Task]):
             Returns None if issue not found.
 
         Raises:
+        ------
             ValueError: If credentials are invalid or query fails
 
         """
@@ -2115,9 +2437,11 @@ class LinearAdapter(BaseAdapter[Task]):
         """List all workflow states for the team.
 
         Args:
+        ----
             team_id: Linear team UUID. If None, uses the configured team.
 
         Returns:
+        -------
             List of workflow state dictionaries with fields:
                 - id: State UUID
                 - name: State name (e.g., "Backlog", "In Progress", "Done")
@@ -2127,6 +2451,7 @@ class LinearAdapter(BaseAdapter[Task]):
                 - position: Position in workflow (lower = earlier)
 
         Raises:
+        ------
             ValueError: If credentials are invalid or query fails
 
         """
@@ -2157,6 +2482,95 @@ class LinearAdapter(BaseAdapter[Task]):
         except Exception as e:
             raise ValueError(f"Failed to list workflow states: {e}") from e
 
+    async def list_epics(
+        self,
+        limit: int = 50,
+        offset: int = 0,
+        state: str | None = None,
+        include_completed: bool = True,
+        **kwargs: Any,
+    ) -> builtins.list[Epic]:
+        """List Linear projects (epics) with efficient pagination.
+
+        Args:
+        ----
+            limit: Maximum number of projects to return (default: 50)
+            offset: Number of projects to skip (note: Linear uses cursor-based pagination)
+            state: Filter by project state (e.g., "planned", "started", "completed", "canceled")
+            include_completed: Whether to include completed projects (default: True)
+            **kwargs: Additional filter parameters (reserved for future use)
+
+        Returns:
+        -------
+            List of Epic objects mapped from Linear projects
+
+        Raises:
+        ------
+            ValueError: If credentials are invalid or query fails
+
+        """
+        # Validate credentials
+        is_valid, error_message = self.validate_credentials()
+        if not is_valid:
+            raise ValueError(error_message)
+
+        await self.initialize()
+        team_id = await self._ensure_team_id()
+
+        # Build project filter using existing helper
+        from .types import build_project_filter
+
+        project_filter = build_project_filter(
+            state=state,
+            team_id=team_id,
+            include_completed=include_completed,
+        )
+
+        try:
+            # Fetch projects with pagination
+            all_projects = []
+            has_next_page = True
+            after_cursor = None
+            projects_fetched = 0
+
+            while has_next_page and projects_fetched < limit + offset:
+                # Calculate how many more we need
+                remaining = (limit + offset) - projects_fetched
+                page_size = min(remaining, 50)  # Linear max page size is typically 50
+
+                variables = {"filter": project_filter, "first": page_size}
+                if after_cursor:
+                    variables["after"] = after_cursor
+
+                result = await self.client.execute_query(LIST_PROJECTS_QUERY, variables)
+
+                projects_data = result.get("projects", {})
+                page_projects = projects_data.get("nodes", [])
+                page_info = projects_data.get("pageInfo", {})
+
+                all_projects.extend(page_projects)
+                projects_fetched += len(page_projects)
+
+                has_next_page = page_info.get("hasNextPage", False)
+                after_cursor = page_info.get("endCursor")
+
+                # Stop if no more results on this page
+                if not page_projects:
+                    break
+
+            # Apply offset and limit
+            paginated_projects = all_projects[offset : offset + limit]
+
+            # Map Linear projects to Epic objects using existing mapper
+            epics = []
+            for project in paginated_projects:
+                epics.append(map_linear_project_to_epic(project))
+
+            return epics
+
+        except Exception as e:
+            raise ValueError(f"Failed to list Linear projects: {e}") from e
+
     async def close(self) -> None:
         """Close the adapter and clean up resources."""
         await self.client.close()
