@@ -16,9 +16,11 @@ def map_linear_issue_to_task(issue_data: dict[str, Any]) -> Task:
     with a parent issue).
 
     Args:
+    ----
         issue_data: Raw Linear issue data from GraphQL
 
     Returns:
+    -------
         Universal Task model
 
     """
@@ -76,6 +78,9 @@ def map_linear_issue_to_task(issue_data: dict[str, Any]) -> Task:
             issue_data["updatedAt"].replace("Z", "+00:00")
         )
 
+    # Extract child issue IDs
+    children = extract_child_issue_ids(issue_data)
+
     # Extract Linear-specific metadata
     linear_metadata = extract_linear_metadata(issue_data)
     metadata = {"linear": linear_metadata} if linear_metadata else {}
@@ -91,6 +96,7 @@ def map_linear_issue_to_task(issue_data: dict[str, Any]) -> Task:
         tags=tags,
         parent_epic=parent_epic,
         parent_issue=parent_issue,
+        children=children,
         created_at=created_at,
         updated_at=updated_at,
         metadata=metadata,
@@ -101,9 +107,11 @@ def map_linear_project_to_epic(project_data: dict[str, Any]) -> Epic:
     """Convert Linear project data to universal Epic model.
 
     Args:
+    ----
         project_data: Raw Linear project data from GraphQL
 
     Returns:
+    -------
         Universal Epic model
 
     """
@@ -165,10 +173,12 @@ def map_linear_comment_to_comment(
     """Convert Linear comment data to universal Comment model.
 
     Args:
+    ----
         comment_data: Raw Linear comment data from GraphQL
         ticket_id: ID of the ticket this comment belongs to
 
     Returns:
+    -------
         Universal Comment model
 
     """
@@ -212,10 +222,12 @@ def build_linear_issue_input(task: Task, team_id: str) -> dict[str, Any]:
     or for a sub-issue when task.parent_issue is provided.
 
     Args:
+    ----
         task: Universal Task model
         team_id: Linear team ID
 
     Returns:
+    -------
         Linear issue input dictionary
 
     """
@@ -250,6 +262,15 @@ def build_linear_issue_input(task: Task, team_id: str) -> dict[str, Any]:
     # Labels are resolved from names to UUIDs in LinearAdapter._create_task()
     # If we set it here, we create a type mismatch (names vs UUIDs)
     # The adapter's label resolution logic (lines 982-988) handles this properly
+    #
+    # Bug Fix (v1.1.1): Previously, setting labelIds to tag names here caused
+    # "Argument Validation Error" from Linear's GraphQL API. The API requires
+    # UUIDs (e.g., "uuid-1"), not names (e.g., "bug"). This was fixed by:
+    # 1. Removing labelIds assignment in mapper (this file)
+    # 2. Adding UUID validation in adapter._create_task() (adapter.py:1047-1060)
+    # 3. Changing GraphQL labelIds type to [String!]! (queries.py)
+    #
+    # See: docs/TROUBLESHOOTING.md#issue-argument-validation-error-when-creating-issues-with-labels
 
     # Add Linear-specific metadata
     if task.metadata and "linear" in task.metadata:
@@ -268,9 +289,11 @@ def build_linear_issue_update_input(updates: dict[str, Any]) -> dict[str, Any]:
     """Build Linear issue update input from update dictionary.
 
     Args:
+    ----
         updates: Dictionary of fields to update
 
     Returns:
+    -------
         Linear issue update input dictionary
 
     """
@@ -320,9 +343,11 @@ def extract_child_issue_ids(issue_data: dict[str, Any]) -> list[str]:
     """Extract child issue IDs from Linear issue data.
 
     Args:
+    ----
         issue_data: Raw Linear issue data from GraphQL
 
     Returns:
+    -------
         List of child issue identifiers
 
     """
